summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/expression_context.h
diff options
context:
space:
mode:
authorMatthew Russotto <matthew.russotto@10gen.com>2017-10-09 17:57:02 -0400
committerMatthew Russotto <matthew.russotto@10gen.com>2017-10-11 08:31:16 -0400
commit767e041931e73ae4f7a0047114becf5be803f3ab (patch)
tree6810e9485838564a5681bb2d8984e7374ec2eb94 /src/mongo/db/pipeline/expression_context.h
parent45d35fe3fcefefe1282b8e0dfc8cd76cb247951d (diff)
downloadmongo-767e041931e73ae4f7a0047114becf5be803f3ab.tar.gz
SERVER-29609 Enable updateLookup for sharded change streams.
Diffstat (limited to 'src/mongo/db/pipeline/expression_context.h')
-rw-r--r--src/mongo/db/pipeline/expression_context.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/mongo/db/pipeline/expression_context.h b/src/mongo/db/pipeline/expression_context.h
index 0e7488aaa55..5bce214c776 100644
--- a/src/mongo/db/pipeline/expression_context.h
+++ b/src/mongo/db/pipeline/expression_context.h
@@ -113,9 +113,10 @@ public:
};
/**
* Convenience call that returns true if the tailableMode indicate a tailable query.
*/
- bool isTailable() const {
+ bool isTailableAwaitData() const {
return tailableMode == TailableMode::kTailableAndAwaitData;
}
@@ -113,9 +113,10 @@ public:
};
/**
- * Convenience call that returns true if the tailableMode indicate a tailable query.
+ * Convenience call that returns true if the tailableMode indicates a tailable and awaitData
+ * query.
*/